..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Installation
============

Invenio-Access is on PyPI so all you need is:

.. code-block:: console

   $ pip install invenio-access

Invenio-Access depends on Invenio-DB and Invenio-Accounts.
